#include <stdio.h>

#include "config.h"

extern char printer[];
extern char outputfile[];
extern char marginx[];
extern char marginy[];
extern int output;
extern char *fontsize[];
extern int fsize;
extern int tab;
extern int pagenum;
extern char *fontstyle[];
extern int fstyle;
extern int border;

void printset( char [] );
void margin( char [] );
void setfonts( char [] );
int outputf( char [] );
int setfontsize( char [] );
void settabsize( char [] );
void showhelp( void );

int setoption( char op[] )
{
	int val;

	switch( op[1] ) {
		case 'f':
			setfonts( op );
			break;
		case 'P':
			printset( op );
			break;
		case 'm':
			margin( op );
			break;
		case 'o':
			if( outputf( op ) < 0 ) {
				fprintf( stderr, "[Usage] htlpr -ooutfile text\n" );
				exit( 1 );
			};
			output = PS;
			break;
		case 's':
			if( setfontsize( op ) < 0 ) {
				fprintf( stderr, "Unknown font size.\n" );
				exit( 1 );
			}	
		case 't':
			settabsize( op );
			break;
		case 'p':
			pagenum = YES;
			break;
		case 'b':
			border = YES;
			break;
		case 'h':
			showhelp();
			exit( 0 );
		default:
			break;
	} 
	return 0;
}

void printset( char op[] )
{
	if( op[2] )
		strcpy( printer, (op+2) );
}

void margin( char op[] )
{
	int i, j;
	char opt[20];

	i = 2;
	j = 0;
	while( op[i] && op[i] != ',' ) {
		opt[j] = op[i];
		i++;
		j++;
	}
	opt[j] = '\0';
	if( opt[0] )
		sprintf( marginx, opt );
	j = 0;
	if( op[i++] == ',' ) {
		while( op[i] ) {
			opt[j] = op[i];
			i++;
			j++;
		}
	}
	else
		return;
	opt[j] = '\0';
	if( opt[0] )
		sprintf( marginy, opt );
}

int outputf( char op[] )
{
	if( !op[2] )
		return -1;
	sprintf( outputfile, (op+2) );
	return 0;
}

int setfontsize( char op[] )
{
	char fs[30];
	int i;

	if( !op[2] )
		return -1;
	sprintf( fs, op+2 );
	for( i = 0; fontsize[i]; i++ ) {
		if( strcmp( fontsize[i], fs ) == 0 ) {
			fsize = i;
			return 0;
		}
	}
	printf( "[Usage] htlpr -sfontsize text\n" );
	printf( "fontsize : " );
	for( i = 0; fontsize[i]; i++ ) 
		printf( "%s\n", fontsize[i] );
	printf( "\n" );
	return -1;
}

void settabsize( char op[] )
{
	char ts[10];

	if( !op[2] )
		return;
	sprintf( ts, op+2 );
	if( ( tab = atoi( ts ) ) <= 0 )
		tab = TAB;
}	

void setfonts( char op[] )
{
	char fs[30];
	int i;

	if( !op[2] )
		;
	else {
		sprintf( fs, op+2 );
		for( i = 0; fontstyle[i]; i++ ) {
			if( strcmp( fontstyle[i], fs ) == 0 ) {
				fstyle = i;
				return;
			}
		}
	}
	printf( "[Usage] htlpr -ffontstyle text\n" );
	printf( "fontstyle : \n" );
	for( i = 0; fontstyle[i]; i++ ) 
		printf( "%s\t", fontstyle[i] );
	printf( "\n" );
	exit( 1 );
}

void showhelp( void )
{
	int i;
	int c;

	char *help[] = {
		"                      This is help for htlpr version 0.52", 
		"",
		"$ htlpr -option hangul_text",
		"",
		"[option]",
		"1) -ffonts",
		"   rm : Roman       it : Italic           sc : Small Caps",
		"   bf : Bold Face   sl : slanted          sf : Sans Seref",
		"   tt : Typewriter",
		"2) -ooutput.ps",
		"   Instead of printing, output output.ps", 
		"3) -Pprinter",
		"   printer : printer name",
		"4) -m-0.3,-0.4",	
		"   topmargin : -0.3, leftmargin : -0.4",
		"5) -sfontsize",
		"   tiny                 scriptsize      footnotesize           small", 
		"   normalsize(default)  large           Large                  LARGE",
		"   huge                 Huge",
		"6) -p",
		"   print page number",
		"7) -b",
		"   print border",
		"8) -t4",
		"   tabsize is 4( default 8 )",
		"9) -h",
		"   This help ",
		( char * )0
	};		

	i = 0;
	while( help[i] ) {
		printf( "%s\n", help[i] );
		i++;
		if( !( i % 23 ) ) {
			printf( "--[7m Press Return [0m--" );
			getchar(); 
		}
	}
}	
