#include <sys/types.h>
#include <sys/wait.h>
#include <unistd.h>
#include <stdio.h>
#include <fcntl.h>
#include <signal.h>

#include "config.h"

extern char tmpf[];
extern char printer[];
extern char curdir[];
extern char outputfile[];

int DoExecuteLatex( void )
{
	pid_t pid;
	int fd[2];
	char file[30];

	sprintf( file, "%s.ks", tmpf );

	if( pipe( fd ) < 0 ) {
		fprintf( stderr, "pipe error\n" );
		return -1;
	}
	if( ( pid = fork() ) < 0 ) {
		fprintf( stderr, "Fork Failure.\n" );
		return -1;
	}
	else if( pid > 0 ) {
		close( fd[1] );
	}
	else if( pid == 0 ) {
		close( fd[0] );
		if( fd[1] != STDOUT_FILENO ) {
			if( dup2( fd[1], STDOUT_FILENO ) != STDOUT_FILENO )
				;
			close( fd[1] );
		}
		if( execl( LATEXPATH, LATEX, file, ( char * )0 ) < 0 ) {
			fprintf( stderr, "hlatex is not exist.\n" );
			return -1;
		}
		exit( 0 );
	}
	if( waitpid( pid, NULL, 0 ) < 0 ) {
		fprintf( stderr, "wait failed.\n" );
		return -1;
	}
	return 0;
}

int DoExecuteDvips( void )
{
	pid_t pid;
	char file[30];
	int fd[2];

	sprintf( file, "%s.dvi", tmpf );

	if( pipe( fd ) < 0 ) {
		fprintf( stderr, "Pipe error\n" );
		return -1;
	}
	if( ( pid = fork() ) < 0 ) {
		fprintf( stderr, "Fork Failure.\n" );
		return -1;
	}
	else if( pid > 0 )
		close( fd[1] );
	else if( pid == 0 ) {
		close( fd[0] );
		if( fd[1] != STDOUT_FILENO ) {
			if( dup2( fd[1], STDOUT_FILENO ) != STDOUT_FILENO )
				;
			close( fd[1] );
		}	
		if( execl( DVIPSPATH, DVIPS, file, ( char * )0 ) < 0 ) {
			fprintf( stderr, "dvips is not exist.\n" );
			return -1;
		}
		exit( 0 );
	}
	if( waitpid( pid, NULL, 0 ) < 0 ) {
		fprintf( stderr, "wait failed.\n" );
		return -1;
	}
	return 0;
}

int DoPrint( void )
{
	pid_t pid;
	char file[30];
	char pr[30];
	int fd[2];

	if( strcmp( printer, "" ) == 0 )
		sprintf( printer, PRINTER );
	
	sprintf( pr, "-P%s", printer );
	sprintf( file, "%s.ps", tmpf );

	if( pipe( fd ) < 0 ) {
		fprintf( stderr, "Pipe error\n" );
		return -1;
	}		
	if( ( pid = fork() ) < 0 ) {
		fprintf( stderr, "Fork Failure.\n" );
		return -1;
	}
	else if( pid > 0 )
		close( fd[1] );
	else if( pid == 0 ) {
		close( fd[0] );
		if( fd[1] != STDOUT_FILENO ) {
			if( dup2( fd[1], STDOUT_FILENO ) < 0 )
				;
			close( fd[1] );
		}
		if( execl( LPRPATH, LPR, pr, file, ( char * )0 ) < 0 ) {
			fprintf( stderr, "lpr is not exist.\n" );
			return -1;
		}
		exit( 1 );
	}
	if( waitpid( pid, NULL, 0 ) < 0 ) {
		fprintf( stderr, "wait failed.\n" );
		return -1;
	}
	return 0;
}

int DoPs( char file[] )
{
	int rfd, wfd;
	int n;
	char output[FILELENGTH];
	char tempfile[FILELENGTH];
	char buf[MAXBUF+1];

	sprintf( output, "%s/%s", curdir, outputfile );
	sprintf( tempfile, "%s.ps", tmpf );

	if( ( rfd = open( tempfile, O_RDONLY ) ) < 0 ) {
		fprintf( stderr, "Cannot open %s.\n", tempfile );	
		exit( 1 );
	}
	if( ( wfd = open( output, O_WRONLY | O_TRUNC | O_CREAT, 0644 ) ) < 0 ) {
		fprintf( stderr, "Cannot open %s.\n", output );	
		exit( 1 );
	}
	while(  ( n = read( rfd, buf, MAXBUF ) ) == MAXBUF )
		write( wfd, buf, n );
	write( wfd, buf, n );
}
